@@ -385,10 +385,11 @@ class RedisProtocol(basic.LineReceiver, policies.TimeoutMixin):
         """
         return self.execute_command("EXISTS", key)
 
-    def delete(self, *keys):
+    def delete(self, keys, *args):
         """
         Delete one or more keys
         """
+        keys = list_or_args("delete", keys, args)
         return self.execute_command("DEL", *keys)
 
     def type(self, key):
@@ -1223,7 +1224,31 @@ class RedisProtocol(basic.LineReceiver, policies.TimeoutMixin):
         """
         return self.execute_command("INFO")
 
-    # monitor and slaveof should are missing
+    # slaveof is missing
+
+
+class MonitorProtocol(RedisProtocol):
+    """
+    monitor has the same behavior as subscribe: hold the connection until
+    something happens.
+
+    take care with the performance impact: http://redis.io/commands/monitor
+    """
+
+    def connectionLost(self, why):
+        pass
+
+    def messageReceived(self, message):
+        pass
+
+    def replyReceived(self, reply):
+        self.messageReceived(reply)
+
+    def monitor(self):
+        return self.execute_command("MONITOR")
+
+    def stop(self):
+        self.transport.loseConnection()
 
 
 class SubscriberProtocol(RedisProtocol):
@@ -1267,6 +1292,12 @@ class SubscriberFactory(protocol.ReconnectingClientFactory):
     protocol = SubscriberProtocol
 
 
+class MonitorFactory(protocol.ReconnectingClientFactory):
+    maxDelay = 120
+    continueTrying = True
+    protocol = MonitorProtocol
+
+
 class ConnectionHandler(object):
     def __init__(self, factory):
         self._factory = factory
@@ -1392,7 +1423,7 @@ class HashRing(object):
     def add_node(self, node):
         self.nodes.append(node)
         for x in xrange(self.replicas):
-            crckey = zlib.crc32("%s:%d" % (node, x))
+            crckey = zlib.crc32("%s:%d" % (node._factory.uuid, x))
             self.ring[crckey] = node
             self.sorted_keys.append(crckey)
 
@@ -1530,7 +1561,7 @@ class RedisFactory(protocol.ReconnectingClientFactory):
     maxDelay = 10
     protocol = RedisProtocol
 
-    def __init__(self, dbid, poolsize, isLazy=False,
+    def __init__(self, uuid, dbid, poolsize, isLazy=False,
                  handler=ConnectionHandler):
         if not isinstance(poolsize, int):
             raise ValueError("Redis poolsize must be an integer, not %s" %
@@ -1540,6 +1571,7 @@ class RedisFactory(protocol.ReconnectingClientFactory):
             raise ValueError("Redis dbid must be an integer, not %s" %
                              repr(dbid))
 
+        self.uuid = uuid
         self.dbid = dbid
         self.poolsize = poolsize
         self.isLazy = isLazy
@@ -1588,7 +1620,8 @@ class RedisFactory(protocol.ReconnectingClientFactory):
 
 
 def makeConnection(host, port, dbid, poolsize, reconnect, isLazy):
-    factory = RedisFactory(dbid, poolsize, isLazy, ConnectionHandler)
+    uuid = "%s:%s" % (host, port)
+    factory = RedisFactory(uuid, dbid, poolsize, isLazy, ConnectionHandler)
     factory.continueTrying = reconnect
     for x in xrange(poolsize):
         reactor.connectTCP(host, port, factory)
@@ -1658,7 +1691,7 @@ def lazyShardedConnectionPool(hosts, dbid=None, poolsize=10, reconnect=True):
 
 
 def makeUnixConnection(path, dbid, poolsize, reconnect, isLazy):
-    factory = RedisFactory(dbid, poolsize, isLazy, UnixConnectionHandler)
+    factory = RedisFactory(path, dbid, poolsize, isLazy, UnixConnectionHandler)
     factory.continueTrying = reconnect
     for x in xrange(poolsize):
         reactor.connectUNIX(path, factory)
@@ -1734,4 +1767,4 @@ __all__ = [
 ]
 
 __author__ = "Alexandre Fiori"
-__version__ = version = "0.6"
+__version__ = version = "0.8"
